@@ -3,8 +3,9 @@ from dateutil.tz import tzlocal
 
 
 def create_log_record(level, message, timestamp=None, metadata=None):
+    timestamp = timestamp or datetime.datetime.now(tz=tzlocal()).isoformat()
     return {
-        'timestamp': timestamp or datetime.datetime.now(tz=tzlocal()).isoformat(),
+        'timestamp': timestamp,
         'level': level,
         'message': message,
         'metadata': metadata or '',
@@ -13,7 +14,8 @@ def create_log_record(level, message, timestamp=None, metadata=None):
 
 def generate_logs(delta=0, n=10):
     """ Generate logs using (a variation of) iso8106 format """
-    m = "[main] org.apache.hadoop.mapreduce: Failed to connect. Executing with tokens: {i}"
+    m = "[main] org.apache.hadoop.mapreduce: " \
+        "Failed to connect. Executing with tokens: {i}"
     now = datetime.datetime.now(tz=tzlocal())
     d = now + datetime.timedelta(days=delta)
     logs = [create_log_record(timestamp=d.isoformat(),
